import zipfile, os, pathlib


def toZip(path_to_zip: str, objects: str):

    with zipfile.ZipFile(path_to_zip, 'w') as ZipArchive:
        for object in objects:
            if os.path.isdir:
                folder = os.path.abspath(object)
                for foldername, subfolders, filenames in os.walk(folder):

                    if foldername == folder:
                        archive_folder_name = ''
                    else:
                        archive_folder_name = os.path.relpath(foldername, folder)
                        ZipArchive.write(foldername, arcname=archive_folder_name)

                    for filename in filenames:
                        ZipArchive.write(os.path.join(foldername, filename), arcname=os.path.join(archive_folder_name, filename))
            elif os.path.isfile(object):
                toZip.write(object, arcname=os.path.join(path_to_zip, os.path.basename(object)))
    

def unzipping(path_to_zip: str, where_to_extract: str = None):
    if where_to_extract == None:
        where_to_extract = path_to_zip
        output_name = os.path.splitext(os.path.basename(where_to_extract))[0]
        where_to_extract = pathlib.Path(path_to_zip).resolve().parent
        where_to_extract = os.path.join(where_to_extract, output_name)

    with zipfile.ZipFile(path_to_zip, 'r') as zipEx:
        zipEx.extractall(where_to_extract)




from unittest import TestCase
import shutil
import filecmp
import hashlib
from os import getcwd, remove
from os.path import join
from pyArchiver.pyArciver import toZip, unzipping


class TestArchiver(TestCase):

    path_to_test = join(getcwd(), 'tests', 'for_test')

    def test_toZip_1(self):
        toZip(join(self.path_to_test, 'vbieTest.zip'), [
            join(self.path_to_test, 'test_folder', 'vbie')
        ])

        with open(join(self.path_to_test, 'vbie.zip'), 'rb') as output, open(join(self.path_to_test, 'vbieTest.zip'), 'rb') as input:
            hashOutputZip = hashlib.sha256(output.read()).digest()
            hashInputZip = hashlib.sha256(input.read()).digest()

            self.assertEqual(hashOutputZip, hashInputZip)

        remove(join(self.path_to_test, 'vbieTest.zip'))

    def test_toZip_2(self):
        toZip(join(self.path_to_test, 'toZip2.zip'), [
            join(self.path_to_test, 'test_folder'),
            join(self.path_to_test, 'test_folder_2'),
            join(self.path_to_test, 'test_file_1.txt'),
        ])

        with open(join(self.path_to_test, 'toZip2.zip'), 'rb') as output, open(join(self.path_to_test, 'test_folder.zip'), 'rb') as input:
            hashOutputZip = hashlib.sha256(output.read()).digest()
            hashInputZip = hashlib.sha256(input.read()).digest()

            self.assertEqual(hashOutputZip, hashInputZip)

        remove(join(self.path_to_test, 'toZip2.zip'))

    def test_unzipping_1(self):
        unzipping(join(self.path_to_test, 'vbie.zip'))

        output_dir = join(self.path_to_test, 'vbie')
        compare = filecmp.dircmp(output_dir, join(self.path_to_test, 'test_folder', 'vbie'))

        self.assertTrue(not len(compare.left_only) and not len(compare.right_only))

        shutil.rmtree(output_dir)



import setuptools
import pyArchiver


with open('README.md') as fr:
    long_description = fr.read()


setuptools.setup(
    name='pyArchiverVadim',
    version=pyArchiver.__version__,
    author='Silenov V.O.',
    author_email='veeeedro@mail.ru',
    description='Archiver',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/veeeedro/pyArchiver',
    packages=setuptools.find_packages(),
    install_requires=[],
    test_suite='tests',
    python_requires='>=3.7',
    platforms=["any"]
)